# Undefined_AD Package

[**Undefined_AD Documentation**](https://cs107-undefined.readthedocs.io/en/latest/)

[![Build Status](https://app.travis-ci.com/cs107-undefined/cs107-FinalProject.svg?branch=final_milestone)](https://app.travis-ci.com/cs107-undefined/cs107-FinalProject)     [![codecov](https://codecov.io/gh/cs107-undefined/cs107-FinalProject/branch/final_milestone/graph/badge.svg?token=MWEZONI94C)](https://codecov.io/gh/cs107-undefined/cs107-FinalProject)

[![Documentation Status](https://readthedocs.org/projects/cs107-undefined/badge/?version=latest)](https://cs107-undefined.readthedocs.io/en/latest/?badge=latest)


## Brief Introduction

This project/package is part of the Harvard CS107/AC207 class final project in Fall 2021, automatic differentiation (AD). We created this package to compute the first-order derivative from a user-defined function automatically. Our package can utilize both forward and reverse modes. Additionally, we also allow users to define their own seeds vector for the Jacobian Matrix and the option to generate the computational graph associated with the input function.

To install, run the following command in your terminal

`pip install undefined_AD`

For details instruction on how to use this package, please follow the steps in the [usage page](https://cs107-undefined.readthedocs.io/en/latest/usage.html).

**Group Number:**

Group 1

**Group Members:**

_Xinran Tang xinran_tang@g.harvard.edu_

_Renhao Luo renhao_luo@hms.harvard.edu_

_Chelse Swoopes cswoopes@g.harvard.edu_

_Shijia Zhang shijiazhang@hms.harvard.edu_

Harvard University, Fall 2021